| License | GPL-2 |
|---|---|
| Maintainer | fuuzetsu@fuuzetsu.co.uk |
| Stability | experimental |
| Portability | portable |
| Safe Haskell | None |
| Language | Haskell2010 |
| Extensions |
|
Data.Trie
Description
An implementation of a trie over a words.
Documentation
fromString :: String -> Trie Source
lookupPrefix :: MonadPlus m => String -> Trie -> m Trie Source
Takes a trie and a prefix and returns the sub-trie that of words with that prefix
forcedNext :: Trie -> String Source
Finds the longest certain path down the trie starting at a the root
Invariant Assumption: All paths have at least one true node below them